﻿using System;
using System.Collections.Generic;
using Wisej.Web;

namespace DynamicDataSourceSample
{
	public partial class Page1 : Page
	{
		/// <summary>
		/// Original full DataSource, can be loaded locally or from a remote DataSource.
		/// </summary>
		private List<MyData> data = new List<MyData>();

		/// <summary>
		/// Filtered DataSource to show in the DataGridView.
		/// </summary>
		private List<MyData> filteredData = new List<MyData>();
		public Page1()
		{
			InitializeComponent();
		}

		/// <summary>
		/// Handles the value assignments to the specified column and row within the DataGridView.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void dataGridView1_CellValueNeeded(object sender, DataGridViewCellValueEventArgs e)
		{
			// Sets the values for the specified columns.
			switch (e.ColumnIndex)
			{
				case 0:
					e.Value = $"ID: {filteredData[e.RowIndex].ID}";
					break;

				case 1:
					e.Value = filteredData[e.RowIndex].Name;
					break;

				default:
					break;

			}
		}

		/// <summary>
		/// Perform search to pull relevant records.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button1_Click(object sender, System.EventArgs e)
		{
			// What is your search query?
			var textToSearch = this.textBox1.Text;
			
			// Fetch the relevant records.
			var results = data.FindAll(item => item.Name.Contains(textToSearch));

			// Handle errors.
			if (results.Count == 0) 
			{
				AlertBox.Show("No results!");
				return;
			}

			// Set the filtered list to the collected results.
			this.filteredData = results;
			// Updates the dataGridView telling it there are x number of records.
			this.dataGridView1.RowCount = this.filteredData.Count;
		}

		/// <summary>
		/// Set an initial dataSource for the DataGridView.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void Page1_Load(object sender, System.EventArgs e)
		{
			var numRecords = 10000;

			for (int i=0; i<numRecords; i++)
			{
				data.Add(new MyData() { ID = i, Name = Guid.NewGuid().ToString() });
			}

			filteredData.AddRange(data);

			// Set to 0 if you don't want to show records on startup.
			this.dataGridView1.RowCount = numRecords;
		}
	}
}
